q1ss.ap.generated
=================

.. automodule:: q1ss.ap.generated

APMatrixGen
-----------

.. autoclass:: q1ss.ap.generated.APMatrixGen
    :show-inheritance:
    :members:
    :special-members: __call__

EyeAPMatrixGen
--------------

.. autoclass:: q1ss.ap.generated.EyeAPMatrixGen
    :show-inheritance:
    :members:
    :special-members: __new__, __call__

GenAP
-----

.. autoclass:: q1ss.ap.generated.GenAP
    :show-inheritance:
    :members:
    :special-members: __new__, __getitem__

RandomAPMatrixGen
-----------------

.. autoclass:: q1ss.ap.generated.RandomAPMatrixGen
    :show-inheritance:
    :members:
    :special-members: __new__, __call__
